# pygelf4ovh
pygelf adaptation that work for OVH Logs Data Platform

## Release note
 - Version 0.2
   * Test done on OVH  Platform 
   * Thanks to : Ivan Mukhin for PyGelf : [PyGelf GitHub project](https://github.com/keeprocking/pygelf)
   
 - Version 0.1
   * Initial commit - first working version